@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "package-utils" "1.0.1"
+(define-package "package-utils" "20250106.1354"
   "Extensions for package.el."
   '((restart-emacs "0.1.1"))
   :url "https://github.com/Silex/package-utils"
-  :commit "5621b95c56b55499f0463fd8b29501da25d861bd"
-  :revdesc "1.0.1-0-g5621b95c56b5"
+  :commit "41c7bf2c0174a9a8bd6efc2260fa9805fbb44c5e"
+  :revdesc "41c7bf2c0174"
   :keywords '("package" "convenience")
   :authors '(("Philippe Vaucher" . "philippe.vaucher@gmail.com"))
   :maintainers '(("Philippe Vaucher" . "philippe.vaucher@gmail.com")))
